@@ -48,6 +48,7 @@ types: list[str] = [
     "AWS::ApiGatewayV2::Model",
     "AWS::ApiGatewayV2::Route",
     "AWS::ApiGatewayV2::RouteResponse",
+    "AWS::ApiGatewayV2::RoutingRule",
     "AWS::ApiGatewayV2::Stage",
     "AWS::ApiGatewayV2::VpcLink",
     "AWS::AppConfig::Application",
@@ -141,8 +142,10 @@ types: list[str] = [
     "AWS::CloudFront::AnycastIpList",
     "AWS::CloudFront::CachePolicy",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity",
+    "AWS::CloudFront::ConnectionGroup",
     "AWS::CloudFront::ContinuousDeploymentPolicy",
     "AWS::CloudFront::Distribution",
+    "AWS::CloudFront::DistributionTenant",
     "AWS::CloudFront::Function",
     "AWS::CloudFront::KeyGroup",
     "AWS::CloudFront::KeyValueStore",
@@ -235,7 +238,6 @@ types: list[str] = [
     "AWS::DataSync::LocationObjectStorage",
     "AWS::DataSync::LocationS3",
     "AWS::DataSync::LocationSMB",
-    "AWS::DataSync::StorageSystem",
     "AWS::DataSync::Task",
     "AWS::Detective::Graph",
     "AWS::Detective::MemberInvitation",
@@ -343,6 +345,7 @@ types: list[str] = [
     "AWS::EC2::VolumeAttachment",
     "AWS::ECR::PullThroughCacheRule",
     "AWS::ECR::RegistryPolicy",
+    "AWS::ECR::RegistryScanningConfiguration",
     "AWS::ECR::ReplicationConfiguration",
     "AWS::ECR::Repository",
     "AWS::ECR::RepositoryCreationTemplate",
@@ -370,9 +373,11 @@ types: list[str] = [
     "AWS::EMR::Step",
     "AWS::EMR::Studio",
     "AWS::EMR::StudioSessionMapping",
+    "AWS::EMR::WALWorkspace",
     "AWS::EMRContainers::VirtualCluster",
     "AWS::EMRServerless::Application",
     "AWS::ElastiCache::CacheCluster",
+    "AWS::ElastiCache::GlobalReplicationGroup",
     "AWS::ElastiCache::ParameterGroup",
     "AWS::ElastiCache::ReplicationGroup",
     "AWS::ElastiCache::SecurityGroup",
@@ -607,6 +612,7 @@ types: list[str] = [
     "AWS::OpenSearchServerless::SecurityConfig",
     "AWS::OpenSearchServerless::SecurityPolicy",
     "AWS::OpenSearchServerless::VpcEndpoint",
+    "AWS::OpenSearchService::Application",
     "AWS::OpenSearchService::Domain",
     "AWS::OpsWorks::App",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment",
@@ -645,6 +651,7 @@ types: list[str] = [
     "AWS::RDS::GlobalCluster",
     "AWS::RDS::Integration",
     "AWS::RDS::OptionGroup",
+    "AWS::RUM::AppMonitor",
     "AWS::Rbin::Rule",
     "AWS::Redshift::Cluster",
     "AWS::Redshift::ClusterParameterGroup",
@@ -701,6 +708,8 @@ types: list[str] = [
     "AWS::S3Outposts::Bucket",
     "AWS::S3Outposts::BucketPolicy",
     "AWS::S3Outposts::Endpoint",
+    "AWS::S3Tables::TableBucket",
+    "AWS::S3Tables::TableBucketPolicy",
     "AWS::SDB::Domain",
     "AWS::SNS::Subscription",
     "AWS::SNS::Topic",
@@ -880,9 +889,7 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
-    "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
-    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -895,7 +902,6 @@ cached: list[str] = [
     "aws-apigateway-vpclink.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
-    "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
     "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
@@ -970,7 +976,6 @@ cached: list[str] = [
     "aws-ce-costcategory.json",
     "aws-certificatemanager-account.json",
     "aws-certificatemanager-certificate.json",
-    "aws-chatbot-customaction.json",
     "aws-chatbot-microsoftteamschannelconfiguration.json",
     "aws-chatbot-slackchannelconfiguration.json",
     "aws-cloud9-environmentec2.json",
@@ -995,8 +1000,10 @@ cached: list[str] = [
     "aws-cloudfront-anycastiplist.json",
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
+    "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
     "aws-cloudfront-distribution.json",
+    "aws-cloudfront-distributiontenant.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
     "aws-cloudfront-keyvaluestore.json",
@@ -1018,7 +1025,6 @@ cached: list[str] = [
     "aws-cloudwatch-dashboard.json",
     "aws-cloudwatch-insightrule.json",
     "aws-cloudwatch-metricstream.json",
-    "aws-codebuild-project.json",
     "aws-codebuild-reportgroup.json",
     "aws-codebuild-sourcecredential.json",
     "aws-codecommit-repository.json",
@@ -1075,7 +1081,6 @@ cached: list[str] = [
     "aws-datasync-locationobjectstorage.json",
     "aws-datasync-locations3.json",
     "aws-datasync-locationsmb.json",
-    "aws-datasync-storagesystem.json",
     "aws-datasync-task.json",
     "aws-detective-graph.json",
     "aws-detective-memberinvitation.json",
@@ -1118,7 +1123,6 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
-    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -1191,6 +1195,7 @@ cached: list[str] = [
     "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
     "aws-ecr-registrypolicy.json",
+    "aws-ecr-registryscanningconfiguration.json",
     "aws-ecr-replicationconfiguration.json",
     "aws-ecr-repository.json",
     "aws-ecr-repositorycreationtemplate.json",
@@ -1212,6 +1217,7 @@ cached: list[str] = [
     "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
+    "aws-elasticache-globalreplicationgroup.json",
     "aws-elasticache-parametergroup.json",
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
@@ -1240,6 +1246,7 @@ cached: list[str] = [
     "aws-emr-step.json",
     "aws-emr-studio.json",
     "aws-emr-studiosessionmapping.json",
+    "aws-emr-walworkspace.json",
     "aws-emrcontainers-virtualcluster.json",
     "aws-emrserverless-application.json",
     "aws-events-apidestination.json",
@@ -1354,6 +1361,7 @@ cached: list[str] = [
     "aws-iot-topicrule.json",
     "aws-iot-topicruledestination.json",
     "aws-kinesis-resourcepolicy.json",
+    "aws-kinesis-stream.json",
     "aws-kinesisanalytics-applicationoutput.json",
     "aws-kinesisanalyticsv2-application.json",
     "aws-kinesisanalyticsv2-applicationoutput.json",
@@ -1393,7 +1401,6 @@ cached: list[str] = [
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
-    "aws-logs-transformer.json",
     "aws-macie-allowlist.json",
     "aws-macie-customdataidentifier.json",
     "aws-macie-findingsfilter.json",
@@ -1418,6 +1425,8 @@ cached: list[str] = [
     "aws-msk-vpcconnection.json",
     "aws-mwaa-environment.json",
     "aws-neptune-dbcluster.json",
+    "aws-neptune-dbclusterparametergroup.json",
+    "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
     "aws-neptune-eventsubscription.json",
     "aws-networkfirewall-firewall.json",
@@ -1441,6 +1450,7 @@ cached: list[str] = [
     "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
     "aws-opensearchserverless-vpcendpoint.json",
+    "aws-opensearchservice-application.json",
     "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
@@ -1523,6 +1533,7 @@ cached: list[str] = [
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
     "aws-route53resolver-resolverrule.json",
     "aws-route53resolver-resolverruleassociation.json",
+    "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
     "aws-s3-accessgrantslocation.json",
@@ -1535,6 +1546,8 @@ cached: list[str] = [
     "aws-s3outposts-bucket.json",
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
+    "aws-s3tables-tablebucket.json",
+    "aws-s3tables-tablebucketpolicy.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
     "aws-sagemaker-coderepository.json",
@@ -1611,7 +1624,6 @@ cached: list[str] = [
     "aws-sqs-queueinlinepolicy.json",
     "aws-sqs-queuepolicy.json",
     "aws-ssm-association.json",
-    "aws-ssm-document.json",
     "aws-ssm-maintenancewindow.json",
     "aws-ssm-maintenancewindowtarget.json",
     "aws-ssm-maintenancewindowtask.json",
@@ -1666,6 +1678,8 @@ cached: list[str] = [
     "aws-wafv2-ipset.json",
     "aws-wafv2-loggingconfiguration.json",
     "aws-wafv2-regexpatternset.json",
+    "aws-wafv2-rulegroup.json",
+    "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
     "aws-workspaces-workspace.json",
     "aws-xray-group.json",
