@@ -51,6 +51,7 @@ types: list[str] = [
     "AWS::ApiGatewayV2::Model",
     "AWS::ApiGatewayV2::Route",
     "AWS::ApiGatewayV2::RouteResponse",
+    "AWS::ApiGatewayV2::RoutingRule",
     "AWS::ApiGatewayV2::Stage",
     "AWS::ApiGatewayV2::VpcLink",
     "AWS::AppConfig::Application",
@@ -223,6 +224,7 @@ types: list[str] = [
     "AWS::DMS::ReplicationInstance",
     "AWS::DMS::ReplicationSubnetGroup",
     "AWS::DMS::ReplicationTask",
+    "AWS::DSQL::Cluster",
     "AWS::DataPipeline::Pipeline",
     "AWS::DataSync::Agent",
     "AWS::DataSync::LocationAzureBlob",
@@ -573,6 +575,7 @@ types: list[str] = [
     "AWS::NetworkManager::CoreNetwork",
     "AWS::NetworkManager::CustomerGatewayAssociation",
     "AWS::NetworkManager::Device",
+    "AWS::NetworkManager::DirectConnectGatewayAttachment",
     "AWS::NetworkManager::GlobalNetwork",
     "AWS::NetworkManager::Link",
     "AWS::NetworkManager::LinkAssociation",
@@ -584,6 +587,13 @@ types: list[str] = [
     "AWS::NetworkManager::VpcAttachment",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
+    "AWS::OpenSearchServerless::AccessPolicy",
+    "AWS::OpenSearchServerless::Collection",
+    "AWS::OpenSearchServerless::Index",
+    "AWS::OpenSearchServerless::LifecyclePolicy",
+    "AWS::OpenSearchServerless::SecurityConfig",
+    "AWS::OpenSearchServerless::SecurityPolicy",
+    "AWS::OpenSearchServerless::VpcEndpoint",
     "AWS::OpenSearchService::Domain",
     "AWS::OpsWorks::App",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment",
@@ -889,7 +899,6 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
-    "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
@@ -901,12 +910,9 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
-    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
-    "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
-    "aws-apigatewayv2-domainname.json",
     "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
@@ -1093,6 +1099,7 @@ cached: list[str] = [
     "aws-dms-replicationinstance.json",
     "aws-dms-replicationsubnetgroup.json",
     "aws-dms-replicationtask.json",
+    "aws-dsql-cluster.json",
     "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
@@ -1111,7 +1118,6 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
-    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -1165,6 +1171,7 @@ cached: list[str] = [
     "aws-ec2-transitgatewayroutetableassociation.json",
     "aws-ec2-transitgatewayroutetablepropagation.json",
     "aws-ec2-transitgatewayvpcattachment.json",
+    "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
     "aws-ec2-vpcblockpublicaccessexclusion.json",
@@ -1191,6 +1198,7 @@ cached: list[str] = [
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
+    "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
@@ -1350,7 +1358,6 @@ cached: list[str] = [
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
-    "aws-logs-transformer.json",
     "aws-m2-application.json",
     "aws-m2-deployment.json",
     "aws-m2-environment.json",
@@ -1413,6 +1420,7 @@ cached: list[str] = [
     "aws-networkmanager-corenetwork.json",
     "aws-networkmanager-customergatewayassociation.json",
     "aws-networkmanager-device.json",
+    "aws-networkmanager-directconnectgatewayattachment.json",
     "aws-networkmanager-globalnetwork.json",
     "aws-networkmanager-link.json",
     "aws-networkmanager-linkassociation.json",
@@ -1424,6 +1432,13 @@ cached: list[str] = [
     "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
+    "aws-opensearchserverless-accesspolicy.json",
+    "aws-opensearchserverless-collection.json",
+    "aws-opensearchserverless-index.json",
+    "aws-opensearchserverless-lifecyclepolicy.json",
+    "aws-opensearchserverless-securityconfig.json",
+    "aws-opensearchserverless-securitypolicy.json",
+    "aws-opensearchserverless-vpcendpoint.json",
     "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
@@ -1503,6 +1518,7 @@ cached: list[str] = [
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-route53resolver-resolverrule.json",
     "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
@@ -1617,7 +1633,6 @@ cached: list[str] = [
     "aws-sqs-queueinlinepolicy.json",
     "aws-sqs-queuepolicy.json",
     "aws-ssm-association.json",
-    "aws-ssm-document.json",
     "aws-ssm-maintenancewindow.json",
     "aws-ssm-maintenancewindowtarget.json",
     "aws-ssm-maintenancewindowtask.json",
