@@ -45,6 +45,7 @@ types: list[str] = [
     "AWS::ApiGatewayV2::Model",
     "AWS::ApiGatewayV2::Route",
     "AWS::ApiGatewayV2::RouteResponse",
+    "AWS::ApiGatewayV2::RoutingRule",
     "AWS::ApiGatewayV2::Stage",
     "AWS::ApiGatewayV2::VpcLink",
     "AWS::AppConfig::Application",
@@ -516,6 +517,13 @@ types: list[str] = [
     "AWS::NetworkManager::VpcAttachment",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
+    "AWS::OpenSearchServerless::AccessPolicy",
+    "AWS::OpenSearchServerless::Collection",
+    "AWS::OpenSearchServerless::Index",
+    "AWS::OpenSearchServerless::LifecyclePolicy",
+    "AWS::OpenSearchServerless::SecurityConfig",
+    "AWS::OpenSearchServerless::SecurityPolicy",
+    "AWS::OpenSearchServerless::VpcEndpoint",
     "AWS::OpenSearchService::Domain",
     "AWS::OpsWorks::App",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment",
@@ -601,6 +609,8 @@ types: list[str] = [
     "AWS::S3::BucketPolicy",
     "AWS::S3ObjectLambda::AccessPoint",
     "AWS::S3ObjectLambda::AccessPointPolicy",
+    "AWS::S3Tables::TableBucket",
+    "AWS::S3Tables::TableBucketPolicy",
     "AWS::SDB::Domain",
     "AWS::SNS::Subscription",
     "AWS::SNS::Topic",
@@ -736,7 +746,6 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
-    "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
@@ -748,12 +757,9 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
-    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
-    "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
-    "aws-apigatewayv2-domainname.json",
     "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
@@ -979,6 +985,7 @@ cached: list[str] = [
     "aws-ec2-transitgatewayroutetableassociation.json",
     "aws-ec2-transitgatewayroutetablepropagation.json",
     "aws-ec2-transitgatewayvpcattachment.json",
+    "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
     "aws-ec2-vpcblockpublicaccessexclusion.json",
@@ -1005,6 +1012,7 @@ cached: list[str] = [
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
+    "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
@@ -1112,7 +1120,6 @@ cached: list[str] = [
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesisanalyticsv2-application.json",
-    "aws-kinesisfirehose-deliverystream.json",
     "aws-kms-alias.json",
     "aws-kms-key.json",
     "aws-kms-replicakey.json",
@@ -1143,7 +1150,6 @@ cached: list[str] = [
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
-    "aws-logs-transformer.json",
     "aws-mediaconnect-flow.json",
     "aws-mediaconnect-flowentitlement.json",
     "aws-mediaconnect-flowoutput.json",
@@ -1197,6 +1203,13 @@ cached: list[str] = [
     "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
+    "aws-opensearchserverless-accesspolicy.json",
+    "aws-opensearchserverless-collection.json",
+    "aws-opensearchserverless-index.json",
+    "aws-opensearchserverless-lifecyclepolicy.json",
+    "aws-opensearchserverless-securityconfig.json",
+    "aws-opensearchserverless-securitypolicy.json",
+    "aws-opensearchserverless-vpcendpoint.json",
     "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
@@ -1220,6 +1233,7 @@ cached: list[str] = [
     "aws-rbin-rule.json",
     "aws-rds-dbcluster.json",
     "aws-rds-dbclusterparametergroup.json",
+    "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
     "aws-rds-dbproxy.json",
     "aws-rds-dbproxyendpoint.json",
@@ -1266,6 +1280,7 @@ cached: list[str] = [
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-route53resolver-resolverrule.json",
     "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
@@ -1276,6 +1291,8 @@ cached: list[str] = [
     "aws-s3-bucketpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
+    "aws-s3tables-tablebucket.json",
+    "aws-s3tables-tablebucketpolicy.json",
     "aws-sagemaker-mlflowtrackingserver.json",
     "aws-sagemaker-modelcard.json",
     "aws-scheduler-schedule.json",
@@ -1325,7 +1342,6 @@ cached: list[str] = [
     "aws-sqs-queueinlinepolicy.json",
     "aws-sqs-queuepolicy.json",
     "aws-ssm-association.json",
-    "aws-ssm-document.json",
     "aws-ssm-maintenancewindow.json",
     "aws-ssm-maintenancewindowtarget.json",
     "aws-ssm-maintenancewindowtask.json",
