@@ -54,6 +54,7 @@ types: list[str] = [
     "AWS::ApiGatewayV2::Model",
     "AWS::ApiGatewayV2::Route",
     "AWS::ApiGatewayV2::RouteResponse",
+    "AWS::ApiGatewayV2::RoutingRule",
     "AWS::ApiGatewayV2::Stage",
     "AWS::ApiGatewayV2::VpcLink",
     "AWS::AppConfig::Application",
@@ -340,16 +341,17 @@ types: list[str] = [
     "AWS::DataSync::LocationObjectStorage",
     "AWS::DataSync::LocationS3",
     "AWS::DataSync::LocationSMB",
-    "AWS::DataSync::StorageSystem",
     "AWS::DataSync::Task",
     "AWS::DataZone::Connection",
     "AWS::DataZone::DataSource",
     "AWS::DataZone::Domain",
+    "AWS::DataZone::DomainUnit",
     "AWS::DataZone::Environment",
     "AWS::DataZone::EnvironmentActions",
     "AWS::DataZone::EnvironmentBlueprintConfiguration",
     "AWS::DataZone::EnvironmentProfile",
     "AWS::DataZone::GroupProfile",
+    "AWS::DataZone::Owner",
     "AWS::DataZone::Project",
     "AWS::DataZone::ProjectMembership",
     "AWS::DataZone::SubscriptionTarget",
@@ -478,6 +480,7 @@ types: list[str] = [
     "AWS::EC2::VolumeAttachment",
     "AWS::ECR::PullThroughCacheRule",
     "AWS::ECR::RegistryPolicy",
+    "AWS::ECR::RegistryScanningConfiguration",
     "AWS::ECR::ReplicationConfiguration",
     "AWS::ECR::Repository",
     "AWS::ECR::RepositoryCreationTemplate",
@@ -896,6 +899,7 @@ types: list[str] = [
     "AWS::Omics::SequenceStore",
     "AWS::Omics::VariantStore",
     "AWS::Omics::Workflow",
+    "AWS::Omics::WorkflowVersion",
     "AWS::OpenSearchServerless::AccessPolicy",
     "AWS::OpenSearchServerless::Collection",
     "AWS::OpenSearchServerless::Index",
@@ -1107,6 +1111,7 @@ types: list[str] = [
     "AWS::SSMContacts::ContactChannel",
     "AWS::SSMContacts::Plan",
     "AWS::SSMContacts::Rotation",
+    "AWS::SSMGuiConnect::Preferences",
     "AWS::SSMIncidents::ReplicationSet",
     "AWS::SSMIncidents::ResponsePlan",
     "AWS::SSMQuickSetup::ConfigurationManager",
@@ -1319,9 +1324,7 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
-    "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
-    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -1334,7 +1337,6 @@ cached: list[str] = [
     "aws-apigateway-vpclink.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
-    "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
     "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
@@ -1410,6 +1412,7 @@ cached: list[str] = [
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
     "aws-auditmanager-assessment.json",
+    "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
     "aws-autoscaling-lifecyclehook.json",
     "aws-autoscaling-scalingpolicy.json",
@@ -1614,16 +1617,17 @@ cached: list[str] = [
     "aws-datasync-locationobjectstorage.json",
     "aws-datasync-locations3.json",
     "aws-datasync-locationsmb.json",
-    "aws-datasync-storagesystem.json",
     "aws-datasync-task.json",
     "aws-datazone-connection.json",
     "aws-datazone-datasource.json",
     "aws-datazone-domain.json",
+    "aws-datazone-domainunit.json",
     "aws-datazone-environment.json",
     "aws-datazone-environmentactions.json",
     "aws-datazone-environmentblueprintconfiguration.json",
     "aws-datazone-environmentprofile.json",
     "aws-datazone-groupprofile.json",
+    "aws-datazone-owner.json",
     "aws-datazone-project.json",
     "aws-datazone-projectmembership.json",
     "aws-datazone-subscriptiontarget.json",
@@ -1688,7 +1692,6 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
-    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -1766,6 +1769,7 @@ cached: list[str] = [
     "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
     "aws-ecr-registrypolicy.json",
+    "aws-ecr-registryscanningconfiguration.json",
     "aws-ecr-replicationconfiguration.json",
     "aws-ecr-repository.json",
     "aws-ecr-repositorycreationtemplate.json",
@@ -1860,8 +1864,6 @@ cached: list[str] = [
     "aws-fsx-volume.json",
     "aws-gamelift-alias.json",
     "aws-gamelift-build.json",
-    "aws-gamelift-fleet.json",
-    "aws-gamelift-gameservergroup.json",
     "aws-gamelift-gamesessionqueue.json",
     "aws-gamelift-location.json",
     "aws-gamelift-script.json",
@@ -2067,12 +2069,12 @@ cached: list[str] = [
     "aws-logs-destination.json",
     "aws-logs-integration.json",
     "aws-logs-loganomalydetector.json",
+    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
-    "aws-logs-transformer.json",
     "aws-lookoutmetrics-alert.json",
     "aws-lookoutmetrics-anomalydetector.json",
     "aws-m2-application.json",
@@ -2175,6 +2177,7 @@ cached: list[str] = [
     "aws-omics-sequencestore.json",
     "aws-omics-variantstore.json",
     "aws-omics-workflow.json",
+    "aws-omics-workflowversion.json",
     "aws-opensearchserverless-accesspolicy.json",
     "aws-opensearchserverless-collection.json",
     "aws-opensearchserverless-index.json",
@@ -2465,6 +2468,7 @@ cached: list[str] = [
     "aws-ssmcontacts-contactchannel.json",
     "aws-ssmcontacts-plan.json",
     "aws-ssmcontacts-rotation.json",
+    "aws-ssmguiconnect-preferences.json",
     "aws-ssmincidents-replicationset.json",
     "aws-ssmincidents-responseplan.json",
     "aws-sso-application.json",
