@@ -717,6 +717,7 @@ cached: list[str] = [
     "aws-apigateway-documentationversion.json",
     "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
+    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -877,8 +878,6 @@ cached: list[str] = [
     "aws-ec2-dhcpoptions.json",
     "aws-ec2-ec2fleet.json",
     "aws-ec2-egressonlyinternetgateway.json",
-    "aws-ec2-eip.json",
-    "aws-ec2-eipassociation.json",
     "aws-ec2-flowlog.json",
     "aws-ec2-gatewayroutetableassociation.json",
     "aws-ec2-host.json",
@@ -893,7 +892,6 @@ cached: list[str] = [
     "aws-ec2-ipamresourcediscoveryassociation.json",
     "aws-ec2-ipamscope.json",
     "aws-ec2-keypair.json",
-    "aws-ec2-launchtemplate.json",
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
@@ -928,6 +926,7 @@ cached: list[str] = [
     "aws-ec2-transitgatewayroutetableassociation.json",
     "aws-ec2-transitgatewayroutetablepropagation.json",
     "aws-ec2-transitgatewayvpcattachment.json",
+    "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
     "aws-ec2-vpcblockpublicaccessexclusion.json",
@@ -949,6 +948,7 @@ cached: list[str] = [
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
+    "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
@@ -1119,7 +1119,6 @@ cached: list[str] = [
     "aws-launchwizard-deployment.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
-    "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
     "aws-logs-logstream.json",
@@ -1152,6 +1151,7 @@ cached: list[str] = [
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
+    "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-instance.json",
