@@ -54,6 +54,7 @@ types: list[str] = [
     "AWS::ApiGatewayV2::Model",
     "AWS::ApiGatewayV2::Route",
     "AWS::ApiGatewayV2::RouteResponse",
+    "AWS::ApiGatewayV2::RoutingRule",
     "AWS::ApiGatewayV2::Stage",
     "AWS::ApiGatewayV2::VpcLink",
     "AWS::AppConfig::Application",
@@ -116,11 +117,13 @@ types: list[str] = [
     "AWS::Batch::SchedulingPolicy",
     "AWS::Bedrock::Agent",
     "AWS::Bedrock::AgentAlias",
+    "AWS::Bedrock::DataSource",
     "AWS::Bedrock::Flow",
     "AWS::Bedrock::FlowAlias",
     "AWS::Bedrock::FlowVersion",
     "AWS::Bedrock::Guardrail",
     "AWS::Bedrock::GuardrailVersion",
+    "AWS::Bedrock::KnowledgeBase",
     "AWS::Bedrock::Prompt",
     "AWS::Bedrock::PromptVersion",
     "AWS::CDK::Metadata",
@@ -270,7 +273,6 @@ types: list[str] = [
     "AWS::DataSync::LocationObjectStorage",
     "AWS::DataSync::LocationS3",
     "AWS::DataSync::LocationSMB",
-    "AWS::DataSync::StorageSystem",
     "AWS::DataSync::Task",
     "AWS::DataZone::DataSource",
     "AWS::DataZone::Domain",
@@ -744,6 +746,7 @@ types: list[str] = [
     "AWS::OpenSearchServerless::SecurityConfig",
     "AWS::OpenSearchServerless::SecurityPolicy",
     "AWS::OpenSearchServerless::VpcEndpoint",
+    "AWS::OpenSearchService::Application",
     "AWS::OpenSearchService::Domain",
     "AWS::OpsWorks::App",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment",
@@ -1087,9 +1090,7 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
-    "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
-    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -1100,12 +1101,9 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
-    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
-    "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
-    "aws-apigatewayv2-domainname.json",
     "aws-apigatewayv2-integration.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
@@ -1177,11 +1175,13 @@ cached: list[str] = [
     "aws-batch-schedulingpolicy.json",
     "aws-bedrock-agent.json",
     "aws-bedrock-agentalias.json",
+    "aws-bedrock-datasource.json",
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
     "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
+    "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
     "aws-bedrock-promptversion.json",
     "aws-cassandra-keyspace.json",
@@ -1315,7 +1315,6 @@ cached: list[str] = [
     "aws-datasync-locationobjectstorage.json",
     "aws-datasync-locations3.json",
     "aws-datasync-locationsmb.json",
-    "aws-datasync-storagesystem.json",
     "aws-datasync-task.json",
     "aws-datazone-datasource.json",
     "aws-datazone-domain.json",
@@ -1362,7 +1361,6 @@ cached: list[str] = [
     "aws-ec2-ec2fleet.json",
     "aws-ec2-egressonlyinternetgateway.json",
     "aws-ec2-eip.json",
-    "aws-ec2-eipassociation.json",
     "aws-ec2-enclavecertificateiamroleassociation.json",
     "aws-ec2-flowlog.json",
     "aws-ec2-gatewayroutetableassociation.json",
@@ -1370,7 +1368,6 @@ cached: list[str] = [
     "aws-ec2-instance.json",
     "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
-    "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
     "aws-ec2-ipampool.json",
     "aws-ec2-ipampoolcidr.json",
@@ -1429,6 +1426,7 @@ cached: list[str] = [
     "aws-ec2-verifiedaccessgroup.json",
     "aws-ec2-verifiedaccessinstance.json",
     "aws-ec2-verifiedaccesstrustprovider.json",
+    "aws-ec2-volume.json",
     "aws-ec2-volumeattachment.json",
     "aws-ec2-vpc.json",
     "aws-ec2-vpcblockpublicaccessexclusion.json",
@@ -1455,6 +1453,7 @@ cached: list[str] = [
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
+    "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
@@ -1681,12 +1680,12 @@ cached: list[str] = [
     "aws-logs-destination.json",
     "aws-logs-integration.json",
     "aws-logs-loganomalydetector.json",
+    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
     "aws-logs-subscriptionfilter.json",
-    "aws-logs-transformer.json",
     "aws-lookoutmetrics-alert.json",
     "aws-lookoutmetrics-anomalydetector.json",
     "aws-m2-application.json",
@@ -1784,6 +1783,7 @@ cached: list[str] = [
     "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
     "aws-opensearchserverless-vpcendpoint.json",
+    "aws-opensearchservice-application.json",
     "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
@@ -1797,6 +1797,7 @@ cached: list[str] = [
     "aws-organizations-organizationalunit.json",
     "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
+    "aws-osis-pipeline.json",
     "aws-pcaconnectorad-connector.json",
     "aws-pcaconnectorad-directoryregistration.json",
     "aws-pcaconnectorad-serviceprincipalname.json",
@@ -1881,6 +1882,7 @@ cached: list[str] = [
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-route53resolver-resolverrule.json",
     "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
