@@ -359,7 +359,6 @@ types: list[str] = [
     "AWS::DataSync::LocationObjectStorage",
     "AWS::DataSync::LocationS3",
     "AWS::DataSync::LocationSMB",
-    "AWS::DataSync::StorageSystem",
     "AWS::DataSync::Task",
     "AWS::DataZone::Connection",
     "AWS::DataZone::DataSource",
@@ -871,6 +870,8 @@ types: list[str] = [
     "AWS::M2::Application",
     "AWS::M2::Deployment",
     "AWS::M2::Environment",
+    "AWS::MPA::ApprovalTeam",
+    "AWS::MPA::IdentitySource",
     "AWS::MSK::BatchScramSecret",
     "AWS::MSK::Cluster",
     "AWS::MSK::ClusterPolicy",
@@ -979,6 +980,7 @@ types: list[str] = [
     "AWS::Omics::SequenceStore",
     "AWS::Omics::VariantStore",
     "AWS::Omics::Workflow",
+    "AWS::Omics::WorkflowVersion",
     "AWS::OpenSearchServerless::AccessPolicy",
     "AWS::OpenSearchServerless::Collection",
     "AWS::OpenSearchServerless::Index",
