@@ -46,6 +46,7 @@ types: list[str] = [
     "AWS::ApiGatewayV2::Model",
     "AWS::ApiGatewayV2::Route",
     "AWS::ApiGatewayV2::RouteResponse",
+    "AWS::ApiGatewayV2::RoutingRule",
     "AWS::ApiGatewayV2::Stage",
     "AWS::ApiGatewayV2::VpcLink",
     "AWS::AppConfig::Application",
@@ -296,7 +297,9 @@ types: list[str] = [
     "AWS::EC2::VerifiedAccessTrustProvider",
     "AWS::EC2::Volume",
     "AWS::EC2::VolumeAttachment",
+    "AWS::ECR::RegistryPolicy",
     "AWS::ECR::RegistryScanningConfiguration",
+    "AWS::ECR::ReplicationConfiguration",
     "AWS::ECR::Repository",
     "AWS::ECS::CapacityProvider",
     "AWS::ECS::Cluster",
@@ -674,6 +677,7 @@ types: list[str] = [
     "AWS::SageMaker::Image",
     "AWS::SageMaker::ImageVersion",
     "AWS::SageMaker::ModelCard",
+    "AWS::SageMaker::Pipeline",
     "AWS::SageMaker::StudioLifecycleConfig",
     "AWS::SageMaker::UserProfile",
     "AWS::SecretsManager::ResourcePolicy",
@@ -779,7 +783,6 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
-    "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
@@ -791,12 +794,9 @@ cached: list[str] = [
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
     "aws-apigateway-vpclink.json",
-    "aws-apigatewayv2-api.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
-    "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
-    "aws-apigatewayv2-domainname.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
     "aws-apigatewayv2-route.json",
@@ -1016,6 +1016,7 @@ cached: list[str] = [
     "aws-ec2-verifiedaccessgroup.json",
     "aws-ec2-verifiedaccessinstance.json",
     "aws-ec2-verifiedaccesstrustprovider.json",
+    "aws-ec2-volume.json",
     "aws-ec2-vpc.json",
     "aws-ec2-vpcblockpublicaccessexclusion.json",
     "aws-ec2-vpcblockpublicaccessoptions.json",
@@ -1030,16 +1031,20 @@ cached: list[str] = [
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
     "aws-ec2-vpngatewayroutepropagation.json",
+    "aws-ecr-registrypolicy.json",
     "aws-ecr-registryscanningconfiguration.json",
+    "aws-ecr-replicationconfiguration.json",
     "aws-ecr-repository.json",
     "aws-ecs-capacityprovider.json",
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
+    "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
     "aws-efs-filesystem.json",
+    "aws-efs-mounttarget.json",
     "aws-eks-accessentry.json",
     "aws-eks-addon.json",
     "aws-eks-cluster.json",
@@ -1235,6 +1240,7 @@ cached: list[str] = [
     "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
     "aws-opensearchserverless-vpcendpoint.json",
+    "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-instance.json",
@@ -1262,6 +1268,9 @@ cached: list[str] = [
     "aws-rds-dbclusterparametergroup.json",
     "aws-rds-dbinstance.json",
     "aws-rds-dbparametergroup.json",
+    "aws-rds-dbproxy.json",
+    "aws-rds-dbproxyendpoint.json",
+    "aws-rds-dbproxytargetgroup.json",
     "aws-rds-dbsecuritygroup.json",
     "aws-rds-dbsecuritygroupingress.json",
     "aws-rds-dbsubnetgroup.json",
@@ -1296,6 +1305,7 @@ cached: list[str] = [
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-route53resolver-resolverrule.json",
     "aws-route53resolver-resolverruleassociation.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
@@ -1316,6 +1326,7 @@ cached: list[str] = [
     "aws-sagemaker-image.json",
     "aws-sagemaker-imageversion.json",
     "aws-sagemaker-modelcard.json",
+    "aws-sagemaker-pipeline.json",
     "aws-sagemaker-studiolifecycleconfig.json",
     "aws-sagemaker-userprofile.json",
     "aws-sdb-domain.json",
@@ -1392,7 +1403,6 @@ cached: list[str] = [
     "aws-stepfunctions-statemachine.json",
     "aws-stepfunctions-statemachinealias.json",
     "aws-stepfunctions-statemachineversion.json",
-    "aws-synthetics-canary.json",
     "aws-synthetics-group.json",
     "aws-transfer-agreement.json",
     "aws-transfer-certificate.json",
@@ -1412,7 +1422,11 @@ cached: list[str] = [
     "aws-waf-sqlinjectionmatchset.json",
     "aws-waf-webacl.json",
     "aws-waf-xssmatchset.json",
+    "aws-wafv2-ipset.json",
     "aws-wafv2-loggingconfiguration.json",
+    "aws-wafv2-regexpatternset.json",
+    "aws-wafv2-rulegroup.json",
+    "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
     "aws-workspaces-workspace.json",
     "aws-workspaces-workspacespool.json",
