@@ -45,6 +45,7 @@ types: list[str] = [
     "AWS::ApiGatewayV2::Model",
     "AWS::ApiGatewayV2::Route",
     "AWS::ApiGatewayV2::RouteResponse",
+    "AWS::ApiGatewayV2::RoutingRule",
     "AWS::ApiGatewayV2::Stage",
     "AWS::ApiGatewayV2::VpcLink",
     "AWS::AppConfig::Application",
@@ -326,6 +327,9 @@ types: list[str] = [
     "AWS::EC2::VerifiedAccessTrustProvider",
     "AWS::EC2::Volume",
     "AWS::EC2::VolumeAttachment",
+    "AWS::ECR::RegistryPolicy",
+    "AWS::ECR::RegistryScanningConfiguration",
+    "AWS::ECR::ReplicationConfiguration",
     "AWS::ECR::Repository",
     "AWS::ECS::CapacityProvider",
     "AWS::ECS::Cluster",
@@ -545,6 +549,9 @@ types: list[str] = [
     "AWS::Lambda::Permission",
     "AWS::Lambda::Version",
     "AWS::LaunchWizard::Deployment",
+    "AWS::Lex::BotAlias",
+    "AWS::Lex::BotVersion",
+    "AWS::Lex::ResourcePolicy",
     "AWS::LicenseManager::Grant",
     "AWS::LicenseManager::License",
     "AWS::Location::GeofenceCollection",
@@ -572,6 +579,11 @@ types: list[str] = [
     "AWS::MSK::ClusterPolicy",
     "AWS::MSK::Configuration",
     "AWS::MSK::VpcConnection",
+    "AWS::MemoryDB::ACL",
+    "AWS::MemoryDB::Cluster",
+    "AWS::MemoryDB::ParameterGroup",
+    "AWS::MemoryDB::SubnetGroup",
+    "AWS::MemoryDB::User",
     "AWS::Neptune::DBCluster",
     "AWS::Neptune::DBClusterParameterGroup",
     "AWS::Neptune::DBInstance",
@@ -754,6 +766,7 @@ types: list[str] = [
     "AWS::SageMaker::ModelPackageGroup",
     "AWS::SageMaker::NotebookInstance",
     "AWS::SageMaker::NotebookInstanceLifecycleConfig",
+    "AWS::SageMaker::Pipeline",
     "AWS::SageMaker::Project",
     "AWS::SageMaker::StudioLifecycleConfig",
     "AWS::SageMaker::UserProfile",
@@ -865,9 +878,7 @@ cached: list[str] = [
     "aws-apigateway-deployment.json",
     "aws-apigateway-documentationpart.json",
     "aws-apigateway-documentationversion.json",
-    "aws-apigateway-domainname.json",
     "aws-apigateway-domainnameaccessassociation.json",
-    "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
     "aws-apigateway-method.json",
     "aws-apigateway-model.json",
@@ -880,7 +891,6 @@ cached: list[str] = [
     "aws-apigateway-vpclink.json",
     "aws-apigatewayv2-apigatewaymanagedoverrides.json",
     "aws-apigatewayv2-apimapping.json",
-    "aws-apigatewayv2-authorizer.json",
     "aws-apigatewayv2-deployment.json",
     "aws-apigatewayv2-integrationresponse.json",
     "aws-apigatewayv2-model.json",
@@ -917,6 +927,7 @@ cached: list[str] = [
     "aws-appstream-stackfleetassociation.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
+    "aws-athena-datacatalog.json",
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
@@ -939,10 +950,12 @@ cached: list[str] = [
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
+    "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
     "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
     "aws-bedrock-promptversion.json",
+    "aws-cassandra-keyspace.json",
     "aws-cassandra-table.json",
     "aws-cassandra-type.json",
     "aws-certificatemanager-account.json",
@@ -975,7 +988,6 @@ cached: list[str] = [
     "aws-codedeploy-application.json",
     "aws-codedeploy-deploymentconfig.json",
     "aws-codedeploy-deploymentgroup.json",
-    "aws-codepipeline-pipeline.json",
     "aws-codepipeline-webhook.json",
     "aws-cognito-identitypool.json",
     "aws-cognito-identitypoolprincipaltag.json",
@@ -1134,7 +1146,6 @@ cached: list[str] = [
     "aws-ec2-vpcblockpublicaccessoptions.json",
     "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
-    "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
     "aws-ec2-vpcendpointservice.json",
     "aws-ec2-vpcendpointservicepermissions.json",
@@ -1143,6 +1154,9 @@ cached: list[str] = [
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
     "aws-ec2-vpngatewayroutepropagation.json",
+    "aws-ecr-registrypolicy.json",
+    "aws-ecr-registryscanningconfiguration.json",
+    "aws-ecr-replicationconfiguration.json",
     "aws-ecr-repository.json",
     "aws-ecs-capacityprovider.json",
     "aws-ecs-cluster.json",
@@ -1153,6 +1167,7 @@ cached: list[str] = [
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
     "aws-efs-filesystem.json",
+    "aws-efs-mounttarget.json",
     "aws-eks-accessentry.json",
     "aws-eks-addon.json",
     "aws-eks-cluster.json",
@@ -1178,9 +1193,9 @@ cached: list[str] = [
     "aws-emr-cluster.json",
     "aws-emr-instancefleetconfig.json",
     "aws-emr-instancegroupconfig.json",
+    "aws-emr-step.json",
     "aws-emrcontainers-virtualcluster.json",
     "aws-emrserverless-application.json",
-    "aws-events-archive.json",
     "aws-events-eventbuspolicy.json",
     "aws-eventschemas-discoverer.json",
     "aws-eventschemas-registry.json",
@@ -1237,6 +1252,7 @@ cached: list[str] = [
     "aws-guardduty-threatintelset.json",
     "aws-iam-accesskey.json",
     "aws-iam-grouppolicy.json",
+    "aws-iam-managedpolicy.json",
     "aws-iam-oidcprovider.json",
     "aws-iam-role.json",
     "aws-iam-rolepolicy.json",
@@ -1300,6 +1316,7 @@ cached: list[str] = [
     "aws-iottwinmaker-syncjob.json",
     "aws-iottwinmaker-workspace.json",
     "aws-kinesis-resourcepolicy.json",
+    "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalytics-applicationoutput.json",
     "aws-kinesisanalyticsv2-application.json",
@@ -1322,6 +1339,9 @@ cached: list[str] = [
     "aws-lambda-function.json",
     "aws-lambda-permission.json",
     "aws-launchwizard-deployment.json",
+    "aws-lex-botalias.json",
+    "aws-lex-botversion.json",
+    "aws-lex-resourcepolicy.json",
     "aws-licensemanager-grant.json",
     "aws-licensemanager-license.json",
     "aws-location-geofencecollection.json",
@@ -1335,7 +1355,6 @@ cached: list[str] = [
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
-    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
@@ -1344,12 +1363,19 @@ cached: list[str] = [
     "aws-m2-application.json",
     "aws-m2-deployment.json",
     "aws-m2-environment.json",
+    "aws-memorydb-acl.json",
+    "aws-memorydb-cluster.json",
+    "aws-memorydb-parametergroup.json",
+    "aws-memorydb-subnetgroup.json",
+    "aws-memorydb-user.json",
     "aws-msk-batchscramsecret.json",
     "aws-msk-cluster.json",
     "aws-msk-clusterpolicy.json",
     "aws-msk-configuration.json",
     "aws-msk-vpcconnection.json",
     "aws-neptune-dbcluster.json",
+    "aws-neptune-dbclusterparametergroup.json",
+    "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
@@ -1372,6 +1398,7 @@ cached: list[str] = [
     "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
     "aws-opensearchserverless-vpcendpoint.json",
+    "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-instance.json",
@@ -1423,13 +1450,10 @@ cached: list[str] = [
     "aws-rds-eventsubscription.json",
     "aws-rds-optiongroup.json",
     "aws-redshift-cluster.json",
-    "aws-redshift-clusterparametergroup.json",
     "aws-redshift-clustersecuritygroup.json",
     "aws-redshift-clustersecuritygroupingress.json",
-    "aws-redshift-clustersubnetgroup.json",
     "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
-    "aws-redshift-eventsubscription.json",
     "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
     "aws-redshiftserverless-workgroup.json",
@@ -1487,6 +1511,7 @@ cached: list[str] = [
     "aws-sagemaker-modelpackagegroup.json",
     "aws-sagemaker-notebookinstance.json",
     "aws-sagemaker-notebookinstancelifecycleconfig.json",
+    "aws-sagemaker-pipeline.json",
     "aws-sagemaker-project.json",
     "aws-sagemaker-studiolifecycleconfig.json",
     "aws-sagemaker-userprofile.json",
@@ -1547,7 +1572,6 @@ cached: list[str] = [
     "aws-sqs-queue.json",
     "aws-sqs-queuepolicy.json",
     "aws-ssm-association.json",
-    "aws-ssm-document.json",
     "aws-ssm-maintenancewindow.json",
     "aws-ssm-maintenancewindowtarget.json",
     "aws-ssm-maintenancewindowtask.json",
@@ -1565,7 +1589,6 @@ cached: list[str] = [
     "aws-stepfunctions-statemachine.json",
     "aws-stepfunctions-statemachinealias.json",
     "aws-stepfunctions-statemachineversion.json",
-    "aws-synthetics-canary.json",
     "aws-synthetics-group.json",
     "aws-timestream-database.json",
     "aws-timestream-scheduledquery.json",
@@ -1576,6 +1599,7 @@ cached: list[str] = [
     "aws-transfer-profile.json",
     "aws-transfer-server.json",
     "aws-transfer-user.json",
+    "aws-transfer-webapp.json",
     "aws-transfer-workflow.json",
     "aws-verifiedpermissions-identitysource.json",
     "aws-verifiedpermissions-policy.json",
@@ -1588,7 +1612,11 @@ cached: list[str] = [
     "aws-waf-sqlinjectionmatchset.json",
     "aws-waf-webacl.json",
     "aws-waf-xssmatchset.json",
+    "aws-wafv2-ipset.json",
     "aws-wafv2-loggingconfiguration.json",
+    "aws-wafv2-regexpatternset.json",
+    "aws-wafv2-rulegroup.json",
+    "aws-wafv2-webacl.json",
     "aws-wafv2-webaclassociation.json",
     "aws-workspaces-workspace.json",
     "aws-workspaces-workspacespool.json",
